# feffery-antd-components
`Plotly Dash`第三方组件库，将`Antd`中的常用组件带入`Dash`的世界🥳，最新版本：`0.0.1a6`

## 1 最新版本安装方式

```bash
pip install feffery-antd-components==0.0.1a6
```

## 2 已实现部件目录

- 日期选择框：`AntdDatePicker`

- 分割线：`AntdDivider`

- 按钮：`AntdButton`

## 3 说明文档

[在线文档地址](http://121.40.46.113:8050/feffery-antd-docs/index)
